@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2020 Rumma 6 Ko Ltd
+# Copyright 2012-2021 Rumma 6 Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from lino_xl.lib.ledger.utils import DC
@@ -8,9 +8,22 @@ from lino.api import dd, rt, _
 
 from lino_xl.lib.vat.choicelists import DeclarationFieldsBase
 from lino_xl.lib.vat.choicelists import VatColumns
-from lino_xl.lib.vat.choicelists import VatRegimes, VatAreas, VatRules
+from lino_xl.lib.vat.choicelists import VatRegimes, VatAreas, VatRules, VatClasses
 from lino_xl.lib.ledger.choicelists import CommonAccounts
 
+
+VatClasses.clear()
+add = VatClasses.add_item
+add('010', _("Goods at normal VAT rate (21%)"), 'goods')    # everything else
+add('020', _("Goods at reduced VAT rate (12%)"), 'reduced')  # food, books,...
+add('030', _("Goods exempt from VAT"), 'exempt')    # post stamps, ...
+add('100', _("Services"), 'services')
+add('200', _("Investments"), 'investments')
+# add('210', _("Real estate"), 'real_estate')
+# add('220', _("Vehicles"), 'vehicles')
+add('300', _("Without VAT"), 'vatless')  # internal clearings, flight tickets, ...
+
+
 NAT = VatAreas.national
 EU = VatAreas.eu
 INT = VatAreas.international
@@ -31,14 +44,30 @@ if True:  # tim2lino can need it
     add('71', _("Luxemburg"), 'lu')
 
 
-VAT_CLASSES_AND_RATES = [("services", "0.21"), ("goods", "0.21"), ("reduced", "0.07")]
+VAT_CLASSES_AND_RATES = [
+    ("goods", "0.21"), ("reduced", "0.12"), ("services", "0.21"), ("investments", "0.21")]
 VatRules.clear()
 add = VatRules.add_item
+#   vat_class rate vat_area trade_type vat_regime  vat_account   vat_returnable_account vat_returnable
+add(None, '0', None, None, "exempt")
+add(None, '0', None, None, "outside")
+
 for vat_class, rate in VAT_CLASSES_AND_RATES:
-    add(vat_class,  rate, NAT,  'purchases', 'subject',  CommonAccounts.vat_deductible)
-    add(vat_class,  rate, EU,   'purchases', 'intracom', CommonAccounts.vat_deductible, CommonAccounts.vat_returnable)
-    add(vat_class,  rate, NAT,  'purchases', 'cocontractor', CommonAccounts.vat_deductible, CommonAccounts.vat_returnable)
-    add(vat_class,  rate, None, 'sales',     None,       CommonAccounts.vat_due)
+    for vat_regime, area in [('intracom', EU), ('cocontractor', NAT)]:
+        add(vat_class, rate, area, 'purchases', vat_regime, CommonAccounts.vat_deductible, CommonAccounts.vat_returnable)
+        add(vat_class, None, area, 'sales',     vat_regime)
+
+for vat_class, rate in VAT_CLASSES_AND_RATES:
+    for vat_regime, area in [('subject', NAT)]:
+        add(vat_class, rate, NAT,  'purchases', vat_regime, CommonAccounts.vat_deductible)
+for vat_class, rate in VAT_CLASSES_AND_RATES:
+    add(vat_class, rate, None, 'sales', None,  CommonAccounts.vat_due)
+
+# for vat_class, rate in VAT_CLASSES_AND_RATES:
+#     add(vat_class,  rate, NAT,  'purchases', 'subject',  CommonAccounts.vat_deductible)
+#     add(vat_class,  rate, EU,   'purchases', 'intracom', CommonAccounts.vat_deductible, CommonAccounts.vat_returnable)
+#     add(vat_class,  rate, NAT,  'purchases', 'cocontractor', CommonAccounts.vat_deductible, CommonAccounts.vat_returnable)
+#     add(vat_class,  rate, None, 'sales',     None,       CommonAccounts.vat_due)
 
 add()
 
