@@ -22,6 +22,7 @@ from etgen.html import E
 from lino import mixins
 from lino.api import dd, rt, gettext, _
 from lino.utils import join_elems
+from lino.core.keyboard import Hotkey
 from lino.core.exceptions import UnresolvedChoice
 from lino.modlib.gfks.mixins import Controllable
 from lino.modlib.users.mixins import UserAuthored, My
@@ -265,6 +266,7 @@ class CreateExcerpt(dd.Action):
     label = _('Print')
     sort_index = 50  # like "Print"
     combo_group = "creacert"
+    hotkey = Hotkey('p', ctrl=True)
 
     def __init__(self, etype, *args, **kwargs):
         self.excerpt_type = etype
