@@ -112,8 +112,7 @@ class PaymentOrder(FinancialVoucher, Printable):
         if ar is None:
             return ''
         elems = []
-        elems.append(ar.instance_action_button(
-            self.write_xml))
+        elems.append(ar.instance_action_button(self.write_xml))
         return E.p(*join_elems(elems, sep=", "))
 
     def get_wanted_movements(self):
