@@ -89,6 +89,8 @@ class Journal(BabelNamed, Sequenced, Referrable, PrintableType):
     #     _("Invert booking direction"),
     #     help_text=_("Whether to invert booking direction of due movement."),
     #     default=True)
+    invoicing_area = dd.ForeignKey('invoicing.Area', blank=True, null=True,
+        related_name="journals_using_this")
 
     def get_doc_model(self):
         """The model of vouchers in this Journal.
@@ -570,7 +572,8 @@ class Voucher(UserAuthored, Duplicable, UploadController, PeriodRangeObservable)
 
     def __str__(self):
         if self.number is None:
-            return "{0}#{1}".format(self.journal.ref, self.id)
+            # return "{0}#{1}".format(self.journal.ref, self.id)
+            return "({0} #{1})".format(self._meta.verbose_name, self.id)
         # moved to implementing subclasses:
         #   if self.state not in dd.plugins.ledger.registered_states:
         #     # raise Exception("20191223 {} is not in {}".format(self.state, dd.plugins.ledger.registered_states))
@@ -805,6 +808,10 @@ class Voucher(UserAuthored, Duplicable, UploadController, PeriodRangeObservable)
         if self.journal_id:
             return self.journal.uploads_volume
 
+    def get_invoicing_area(self):
+        # used by InvoiceGenerator.
+        return self.journal.invoicing_area
+
 
 Voucher.set_widget_options('number_with_year', width=10)
 # Voucher.set_widget_options('number', hide_sum=True)
@@ -816,7 +823,10 @@ class ToggleState(dd.Action):
     # sort_index = 52
     label = _("Toggle state")
     # action_name = "changemystate"
-    button_text = "⏼" # 23FC Toggle power
+    # button_text = "⏼" # 23FC Toggle power
+    # button_text = "⇄" # 21c4
+    # button_text = "⇌" # 21cc
+    button_text = "⇅" # 21c5
     hotkey = Hotkey('x', ctrl=True)
 
     def run_from_ui(self, ar, **kw):
@@ -849,7 +859,8 @@ class RegistrableVoucher(Registrable, Voucher):
         # if not isinstance(self.state, dd.plugins.ledger.registered_states):
         if self.hide_editable_number and self.state.is_editable:
             # raise Exception("20191223 {} is not in {}".format(self.state, dd.plugins.ledger.registered_states))
-            return "{0} #{1}".format(self.journal.ref, self.id)
+            return "({0} #{1})".format(self._meta.verbose_name, self.id)
+            # return "{0} #{1}".format(self.journal.ref, self.id)
         return super(RegistrableVoucher, self).__str__()
 
     def after_state_change(self, ar, oldstate, newstate):
