@@ -1,9 +1,7 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2018 Rumma & Ko Ltd
+# Copyright 2009-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-from builtins import str
-
 from django.conf import settings
 from django.db import models
 from django.utils.translation import gettext_lazy as _
@@ -31,7 +29,6 @@ from .roles import NotesUser, NotesStaff
 from lino.modlib.notify.choicelists import MessageTypes
 MessageTypes.add_item('notes', dd.plugins.notes.verbose_name)
 
-
 from .choicelists import SpecialTypes
 
 
@@ -135,8 +132,8 @@ class Note(TypedPrintable,
 
     def __str__(self):
         if self.event_type_id:
-            return u'%s #%s' % (self.event_type, self.pk)
-        return u'%s #%s' % (self._meta.verbose_name, self.pk)
+            return '%s #%s' % (self.event_type, self.pk)
+        return '%s #%s' % (self._meta.verbose_name, self.pk)
 
     def summary_row(self, ar, **kw):
         #~ s = super(Note,self).summary_row(ui,rr)
