@@ -9,6 +9,7 @@ from django.utils.translation import get_language
 
 from lino.api import dd, rt, _
 from etgen.html import E, tostring_pretty
+from lino.core import constants
 from lino.core.renderer import add_user_language
 
 from lino.utils.mldbc.fields import LanguageField
@@ -170,6 +171,10 @@ class Pages(dd.Table):
     order_by = ["ref"]
 
 
+class PublicPages(Pages):
+    display_mode = constants.DISPLAY_MODE_STORY
+
+
 #~ class MyPages(ByUser,Pages):
     #~ required = dict(user_groups='office')
     #~ column_names = "modified title type project *"
