@@ -2,7 +2,7 @@
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Adds functionality for handling sales.
-See :doc:`/specs/sales`.
+See :doc:`/plugins/sales`.
 
 """
 
