@@ -203,9 +203,12 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
             return str(site)
         return site.obj2href(ar)
 
+    # def get_invoice_recipient(self):
+    #     return self.invoice_recipient
+
     def get_invoiceable_partner(self):
         if self.ticket_id and self.ticket.site_id:
-            return self.ticket.site.company
+            return self.ticket.site.get_invoiceable_partner()
 
     def get_invoiceable_product(self, max_date=None):
         par = self.get_invoiceable_partner()
@@ -225,13 +228,24 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
         # pre-select all Event objects that potentially will generate
         # an invoice.
 
-        qs = cls.objects.all()
+        qs = super(Session, cls).get_generators_for_plan(plan, partner)
+
+        max_date = plan.get_max_date()
+        if max_date:
+            qs = qs.filter(start_date__lte=max_date)
+        if plan.min_date:
+            qs = qs.filter(start_date__gte=plan.min_date)
+
+        # qs = cls.objects.all()
         # qs = qs.filter(state=EntryStates.took_place)
         # if plan.area_id:
         #     qs = qs.filter(room__invoicing_area=plan.area)
-        #
-        # if plan.order is not None:
-        #     qs = qs.filter(**gfk2lookup(cls.owner, plan.order))
+
+        if plan.order is not None:
+            # raise Exception("20210731 {}".format(dd.plugins.invoicing.order_model))
+            # qs = qs.filter(**gfk2lookup(cls.owner, plan.order))
+            if dd.plugins.invoicing.order_model is rt.models.orders.Order:
+                qs = qs.filter(ticket__site__order=plan.order)
 
         # dd.logger.info("20181113 c %s", qs)
 
@@ -239,16 +253,18 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
             partner = plan.partner
 
         if partner is None:
-            # only courses with a partner (because only these get invoiced
+            # only with a partner (because only these get invoiced
             # per course).
             qs = qs.filter(ticket__site__company__isnull=False)
         else:
-            q1 = models.Q(
-                ticket__site__company__salesrule__invoice_recipient__isnull=True,
-                ticket__site__company=partner)
-            q2 = models.Q(
-                ticket__site__company__salesrule__invoice_recipient=partner)
-            qs = qs.filter(models.Q(q1 | q2))
+            fldname = rt.models.tickets.Site.get_partner_filter_field(partner)
+            qs = cls.filter_by_invoice_recipient(qs, partner, 'ticket__site__'+fldname)
+            # q1 = models.Q(
+            #     ticket__site__company__salesrule__invoice_recipient__isnull=True,
+            #     ticket__site__company=partner)
+            # q2 = models.Q(
+            #     ticket__site__company__salesrule__invoice_recipient=partner)
+            # qs = qs.filter(models.Q(q1 | q2))
 
         # dd.logger.info("20200518 %s (%d rows)", qs.query, qs.count())
         return qs.order_by('id')
